/// <reference types="bn.js" />
import { Connection, PublicKey } from "@solana/web3.js";
import { PDA } from "../pda";
import { CachedContent, CachedValue } from "./fetcher";
import { EscrowConfigData, KycCertData, OfferData, TokenInfoData, TradeData } from "../types";
import { BN } from "@project-serum/anchor";
export declare class EscrowFetcher {
    private readonly fetcher;
    pda: PDA;
    connection: Connection;
    constructor(connection: Connection, pda: PDA, cache?: Record<string, CachedContent<CachedValue>>);
    getConfigData(): Promise<EscrowConfigData | null>;
    getConfigAddress(): PublicKey;
    getTrade(tradeId: BN): Promise<TradeData | null>;
    getTrades(startTradeId: number, endTradeId?: number): Promise<(TradeData | null)[]>;
    getTradesByStatus(tradeStatus: object): Promise<(TradeData | null)[]>;
    getTradesByBuyerAddress(address: PublicKey): Promise<(TradeData | null)[]>;
    getTradesBySellerAddress(address: PublicKey): Promise<(TradeData | null)[]>;
    getOffer(offerId: BN): Promise<OfferData | null>;
    getOffers(startOfferId: number, endOfferId?: number): Promise<(OfferData | null)[]>;
    getAllTradesOfAnOffer(offerId: BN): Promise<(TradeData | null)[]>;
    getAllTrades(): Promise<(TradeData | null)[]>;
    getKYCCertData(tokenMint: PublicKey, userPubkey: PublicKey): Promise<KycCertData | null>;
    getTokenInfoData(tokenMint: PublicKey): Promise<TokenInfoData | null>;
    isArbitrator(userPubkey: PublicKey): Promise<boolean>;
    refreshAll(): Promise<void>;
}
